@@ -13,18 +13,19 @@
 # limitations under the License.
 """Parsers for ECMWF download configuration."""
 
+import ast
 import configparser
 import copy as cp
 import datetime
 import json
-import ast
 import string
 import textwrap
 import typing as t
-from .config import Config
-from urllib.parse import urlparse
 from collections import OrderedDict
+from urllib.parse import urlparse
+
 from .clients import CLIENTS
+from .config import Config
 from .manifest import MANIFESTS, Manifest, Location, NoOpManifest
 
 
@@ -106,7 +107,7 @@ def day_month_year(candidate: t.Any) -> int:
     try:
         if isinstance(candidate, str) or isinstance(candidate, int):
             return int(candidate)
-        raise
+        raise ValueError('must be a str or int.')
     except ValueError as e:
         raise ValueError(
             f"Not a valid day, month, or year value: {candidate}. Please use valid value."
@@ -115,6 +116,9 @@ def day_month_year(candidate: t.Any) -> int:
 
 def parse_literal(candidate: t.Any) -> t.Any:
     try:
+        # Support parsing ints with leading zeros, e.g. '01'
+        if isinstance(candidate, str) and candidate.isdigit():
+            return int(candidate)
         return ast.literal_eval(candidate)
     except (ValueError, TypeError, SyntaxError, MemoryError, RecursionError):
         return candidate
@@ -292,7 +296,11 @@ def _parse_lists(config_parser: configparser.ConfigParser, section: str = '') ->
 
 
 def _number_of_replacements(s: t.Text):
-    return len([v for v in string.Formatter().parse(s) if v[1] is not None])
+    format_names = [v[1] for v in string.Formatter().parse(s) if v[1] is not None]
+    num_empty_names = len([empty for empty in format_names if empty == ''])
+    if num_empty_names != 0:
+        num_empty_names -= 1
+    return len(set(format_names)) + num_empty_names
 
 
 def parse_subsections(config: t.Dict) -> t.Dict:
@@ -398,9 +406,18 @@ def process_config(file: t.IO) -> Config:
             partition keys.
             """.format(num_template_replacements, num_partition_keys))
 
+    if 'day' in partition_keys:
+        require(selection['day'] != 'all',
+                """If 'all' is used for a selection value, it cannot appear as a partition key.""")
+
     # Ensure consistent lookup.
     config['parameters']['partition_keys'] = partition_keys
 
+    # Ensure the cartesian-cross can be taken on singleton values for the partition.
+    for key in partition_keys:
+        if not isinstance(selection[key], list):
+            selection[key] = [selection[key]]
+
     return Config.from_dict(config)
 
 
