@@ -20,7 +20,8 @@ import tempfile
 import typing as t
 
 from apache_beam.io.filesystems import FileSystems
-from apache_beam.utils import retry
+
+from .util import retry_with_exponential_backoff
 
 
 class Store(abc.ABC):
@@ -97,8 +98,7 @@ class LocalFileStore(Store):
 class FSStore(Store):
     """Store data into any store supported by Apache Beam's FileSystems."""
 
-    @retry.with_exponential_backoff(
-        retry_filter=retry.retry_if_valid_input_but_server_error_and_timeout_filter)
+    @retry_with_exponential_backoff
     def open(self, filename: str, mode: str = 'r') -> t.IO:
         """Open object in cloud bucket (or local file system) as a read or write channel.
 
